about summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--ops/nixos/monorepo-gerrit.nix20
1 files changed, 10 insertions, 10 deletions
diff --git a/ops/nixos/monorepo-gerrit.nix b/ops/nixos/monorepo-gerrit.nix
index 003088fde6..185ff92b4f 100644
--- a/ops/nixos/monorepo-gerrit.nix
+++ b/ops/nixos/monorepo-gerrit.nix
@@ -43,18 +43,18 @@ in {
         "pull"
       ];
 
       # Configure for cgit.
       gitweb = {
         type = "custom";
-        url = "https://code.tvl.fyi";
-        project = "/";
-        revision = "/commit/?id=\${commit}";
-        branch = "/log/?h=\${branch}";
-        tag = "/tag/?h=\${tag}";
-        roottree = "/tree/?h=\${commit}";
-        file = "/tree/\${file}?h=\${commit}";
-        filehistory = "/log/\${file}?h=\${branch}";
-        linkname = "cgit";
+        url = "https://cs.tvl.fyi";
+        linkname = "Sourcegraph";
+        project = "/depot";
+        revision = "/depot/-/commit/\${commit}";
+        branch = "/depot@\${branch}";
+        tag = "/depot@\${tag}";
+        roottree = "/depot@\${commit}";
+        file = "/depot@\${commit}/-/blob/\${file}";
+        filehistory = "/depot@\${commit}/-/blob/\${file}#&tab=history";
       };
 
       # Configures integration with the locally running OpenLDAP
@@ -43,18 +43,18 @@ in {
       ];
 
-      # Configure for cgit.
+      # Configure for Sourcegraph.
       gitweb = {
         type = "custom";